pub struct DeclUse<Sym> {
pub declared_symbols: Vec<Sym>,
pub used_symbols: Vec<Sym>,
}Expand description
Collection of defined and used symbols in a file or segment of code.
Fields
declared_symbols: Vec<Sym>Declared in the code. They can be imported from elsewhere, predeclared in a header file etc. or defined locally.
used_symbols: Vec<Sym>Appearing in a right-hand-side or evaluation context, such as member access, function call etc.
Implementations
Sourceimpl DeclUse<SimpleName>
impl DeclUse<SimpleName>
Sourcepub fn within_extent(&self, extent: &Extent) -> Self
pub fn within_extent(&self, extent: &Extent) -> Self
Narrow down the names to a specific extent by filtering out those declarations and usages which do not overlap with the provided extent.
pub fn filter_matches(&self, names: &HashSet<&str>) -> Self
Sourceimpl DeclUse<FullyQualifiedName>
impl DeclUse<FullyQualifiedName>
Sourcepub fn within_extent(&self, extent: &Extent) -> Self
pub fn within_extent(&self, extent: &Extent) -> Self
Narrow down the names to a specific extent by filtering out those declarations and usages which do not overlap with the provided extent.
pub fn filter_matches(&self, names: &HashSet<&str>) -> Self